@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class KADDRESSBOOK_IMPORTEXPORT_EXPORT KAddressBookImportExportPlugin : public P
 {
     Q_OBJECT
 public:
-    explicit KAddressBookImportExportPlugin(QObject *parent = Q_NULLPTR);
+    explicit KAddressBookImportExportPlugin(QObject *parent = nullptr);
     ~KAddressBookImportExportPlugin();
 };
 }
